@@ -31,7 +31,6 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'getResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201302::RequestContextOperand',
                'mutateResponse' => 'Google::Ads::AdWords::v201302::AdGroupFeedService::mutateResponse',
-               'get/selector/dateRange/max/month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201302::RateExceededError::Reason',
                'mutate/operations/operand/matchingFunction' => 'Google::Ads::AdWords::v201302::Function',
                'mutate/operations/operand/matchingFunction/operator' => 'Google::Ads::AdWords::v201302::Function::Operator',
@@ -70,7 +69,6 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/max/year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'get' => 'Google::Ads::AdWords::v201302::AdGroupFeedService::get',
                'mutate/operations/operand/matchingFunction/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -82,14 +80,13 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201302::QuotaCheckError',
                'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/min/day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
                'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
                'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201302::BetaError',
                'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201302::RateExceededError',
                'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/max' => 'Google::Ads::AdWords::v201302::Date',
+               'get/selector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -98,7 +95,6 @@ our $typemap_1 = {
                'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutateResponse/rval/value/matchingFunction/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201302::FeedAttributeOperand',
-               'get/selector/dateRange/min/year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'getResponse/rval/entries/matchingFunction/rhsOperand' => 'Google::Ads::AdWords::v201302::FunctionArgumentOperand',
                'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutateResponse/rval/value/matchingFunction/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
@@ -151,7 +147,6 @@ our $typemap_1 = {
                'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
                'getResponse/rval' => 'Google::Ads::AdWords::v201302::AdGroupFeedPage',
                'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201302::ClientTermsError',
-               'get/selector/dateRange/min/month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[FunctionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[FunctionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -171,7 +166,7 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201302::InternalApiError::Reason',
-               'get/selector/dateRange/min' => 'Google::Ads::AdWords::v201302::Date',
+               'get/selector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -297,8 +292,8 @@ our $typemap_1 = {
                'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201302::RangeError::Reason',
                'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201302::ConstantOperand',
-               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]' => 'Google::Ads::AdWords::v201302::AdGroupFeedError',
                'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
+               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]' => 'Google::Ads::AdWords::v201302::AdGroupFeedError',
                'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201302::ReadOnlyError',
                'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201302::RequestError',
@@ -318,7 +313,6 @@ our $typemap_1 = {
                'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
                'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201302::ConstantOperand',
-               'get/selector/dateRange/max/day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'getResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201302::FeedAttributeOperand',
                'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'getResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201302::FeedAttributeOperand',
@@ -331,8 +325,8 @@ our $typemap_1 = {
                'get/selector' => 'Google::Ads::AdWords::v201302::Selector',
                'Fault/detail/ApiExceptionFault/errors[FunctionError]/reason' => 'Google::Ads::AdWords::v201302::FunctionError::Reason',
                'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201302::SelectorError',
-               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'getResponse/rval/entries/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
+               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutate/operations' => 'Google::Ads::AdWords::v201302::AdGroupFeedOperation'
              };
 ;
