@@ -10,7 +10,6 @@ our $typemap_1 = {
                'mutate/operations/operand/attributes/type' => 'Google::Ads::AdWords::v201302::FeedAttribute::Type',
                'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201302::ClientTermsError',
                'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/min/month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201302::AuthenticationError::Reason',
                'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -39,8 +38,7 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201302::InternalApiError::Reason',
                'mutateResponse' => 'Google::Ads::AdWords::v201302::FeedService::mutateResponse',
-               'get/selector/dateRange/max/month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
-               'get/selector/dateRange/min' => 'Google::Ads::AdWords::v201302::Date',
+               'get/selector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201302::RateExceededError::Reason',
                'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -105,7 +103,6 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201302::IdError::Reason',
-               'get/selector/dateRange/max/year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'getResponse/rval/entries/attributes/type' => 'Google::Ads::AdWords::v201302::FeedAttribute::Type',
                'get' => 'Google::Ads::AdWords::v201302::FeedService::get',
@@ -127,7 +124,6 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201302::QuotaCheckError',
                'Fault/detail/ApiExceptionFault/errors[FeedError]' => 'Google::Ads::AdWords::v201302::FeedError',
                'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/min/day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'getResponse/rval/entries/attributes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutate' => 'Google::Ads::AdWords::v201302::FeedService::mutate',
                'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -137,7 +133,7 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
-               'get/selector/dateRange/max' => 'Google::Ads::AdWords::v201302::Date',
+               'get/selector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
                'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201302::ApiError',
@@ -147,13 +143,12 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
+               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutateResponse/rval/value/attributes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/min/year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
                'get/selector/ordering' => 'Google::Ads::AdWords::v201302::OrderBy',
@@ -220,10 +215,9 @@ our $typemap_1 = {
                'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'mutateResponse/rval/value/attributes/isPartOfKey' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
                'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201302::NullError',
-               'getResponse/rval/entries/attributes' => 'Google::Ads::AdWords::v201302::FeedAttribute',
                'get/selector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
+               'getResponse/rval/entries/attributes' => 'Google::Ads::AdWords::v201302::FeedAttribute',
                'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
-               'get/selector/dateRange/max/day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
                'mutate/operations/operand' => 'Google::Ads::AdWords::v201302::Feed',
                'getResponse' => 'Google::Ads::AdWords::v201302::FeedService::getResponse',
                'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
